@@ -15,30 +15,14 @@ class NextCloud(HomeServerApp):
         self.fix_permissions()
         self.logger.debug('Installing nextcloud')
         self.install()
-        self.logger.debug('Creating new user')
-        self.create_users()
         self.logger.debug('Setting up nginx paths')
         self.setup_paths()
         self.logger.debug('Installing external links apps')
         self.install_external_links()
         self.logger.debug('Setting up onlyoffice')
         self.setup_onlyoffice()
-        self.logger.debug('Setting up music')
-        self.setup_music()
-        self.logger.debug('Setting up SMS sync')
-        self.setup_ocsms()
-        self.logger.debug('Setting up tasks')
-        self.setup_tasks()
-        self.logger.debug('Setting up calendar')
-        self.setup_calendar()
-        self.logger.debug('Setting up carnet')
-        self.setup_carnet()
-        self.logger.debug('Setting up keepass web')
-        self.setup_keeweb()
-        self.logger.debug('Setting up deck')
-        self.setup_deck()
-        self.logger.debug('Setting up contacts')
-        self.setup_contacts()
+        self.logger.debug('Installing apps')
+        self.setup_apps()
         self.logger.debug('Set up nextcloud')
 
     def fix_permissions(self):
@@ -50,44 +34,17 @@ class NextCloud(HomeServerApp):
         self.occ('maintenance:install', '--data-dir', '/data', '--admin-pass',
                  self.password, '--admin-user', 'admin')
 
-    def create_users(self):
-        self.occ('user:add', '--password-from-env', '--display-name',
-                 self.meta['nextcloud_username'],
-                 self.meta['nextcloud_username'])
-
     def setup_paths(self):
         self.occ('config:system:set', 'overwritewebroot', '--value', '/')
         self.occ('config:system:set', 'overwriteprotocol', '--value', 'https')
         self.occ('config:system:set', 'trusted_domains', '0', '--value',
                  f'private.{self.domain}')
 
-    def setup_music(self):
-        self.occ('app:install', 'music')
-
-    def setup_ocsms(self):
-        self.occ('app:install', 'ocsms')
-
-    def setup_tasks(self):
-        self.occ('app:install', 'tasks')
-
-    def setup_calendar(self):
-        """Setup calendar"""
-        self.occ('app:install', 'calendar')
-
-    def setup_carnet(self):
-        """Setup carnet note-taking app"""
-        self.occ('app:install', 'carnet')
-
-    def setup_deck(self):
-        """Setup deck kanban"""
-        self.occ('app:install', 'deck')
-
-    def setup_contacts(self):
-        """Setup contacts"""
-        self.occ('app:install', 'contacts')
-
-    def setup_keeweb(self):
-        self.occ('app:install', 'keeweb')
+    def setup_apps(self):
+        apps = ('ocsms', 'tasks', 'calendar', 'deck', 'contacts', 'side_menu',
+                'maps', 'breezedark')
+        for app in apps:
+            self.occ('app:install', app)
 
     def install_external_links(self):
         """Install top links to all the rest of apps, to centralice everything on nextcloud"""
@@ -183,8 +140,7 @@ class NextCloud(HomeServerApp):
                 dict(user='www-data',
                      stdout=True,
                      demux=False,
-                     stderr=False,
-                     environment={'OC_PASS': self.meta['nextcloud_password']}))
+                     stderr=False))
             result = self.container.exec_run(args, **kwargs)
             self.logger.debug(result)
             return result[1]
